@@ -5,19 +5,19 @@
 #' @importFrom stats qnorm
 #' @description This function builds a ggplot object to compare the sample
 #'   means of the (weighted) number of records in a vector up to time \eqn{t}, 
-#'   \eqn{\bar N_{t.}^\omega}, and the expected values 
+#'   \eqn{\bar N_{t}^\omega}, and the expected values 
 #'   \eqn{\textrm{E}(N_t^{\omega})} 
 #'   under the classical record model (i.e., of IID continuous RVs).
 #' @details 
 #'   This plot is associated to the test \code{\link{N.test}}.
 #'   It calculates the sample means of the number of records in a set of
 #'   vectors up to every time \eqn{t} (see \code{\link{Nmean.record}}). 
-#'   These sample means \eqn{\bar N_{t.}^\omega} are calculated from the sample of
+#'   These sample means \eqn{\bar N_{t}^\omega} are calculated from the sample of
 #'   \eqn{M} values obtained from \eqn{M} vectors, the columns of matrix 
 #'   \code{X}. Then, these values are plotted and compared with the expected 
-#'   values \eqn{\textrm{E}(N_t^{\omega})} and their confidence intervals (CIs), under
-#'   the hypothesis of the classical record model. The CIs of 
-#'   \eqn{\bar N_{t.}^\omega} uses the fact that, under the classical record 
+#'   values \eqn{\textrm{E}(N_t^{\omega})} and their reference intervals (RIs), under
+#'   the hypothesis of the classical record model. The RIs of 
+#'   \eqn{\bar N_{t}^\omega} uses the fact that, under the classical record 
 #'   model, the statistic is asymptotically Normal.
 #'   
 #'   The plot can show the four types of record at the same time (i.e., 
@@ -30,7 +30,7 @@
 #'   \code{backward}).
 #'   
 #'   More details of this plot are shown in Cebrián, Castillo-Mateo, Asín 
-#'   (2021).
+#'   (2022).
 #'   
 #' @param X A numeric vector, matrix (or data frame).
 #' @param weights A function indicating the weight given to the different 
@@ -49,24 +49,25 @@
 #' @param point.col,point.shape Vector with four elements indicating the colour
 #'   and shape of the points. Every one of the four elements represents forward
 #'   upper, forward lower, backward upper and backward lower, respectively.
-#' @param conf.int Logical. Indicates if the CIs are also shown.
-#' @param conf.level (If \code{conf.int == TRUE}) Confidence level of the CIs.
+#' @param conf.int Logical. Indicates if the RIs are also shown.
+#' @param conf.level (If \code{conf.int == TRUE}) Confidence level of the RIs.
 #' @param conf.aes (If \code{conf.int == TRUE}) A character string indicating 
-#'   the aesthetic to display for the CIs, \code{"ribbon"} (grey area) or 
+#'   the aesthetic to display for the RIs, \code{"ribbon"} (grey area) or 
 #'   \code{"errorbar"} (vertical lines).
 #' @param conf.col Colour used to plot the expected value and (if 
-#'   \code{conf.int == TRUE}) CIs.
+#'   \code{conf.int == TRUE}) RIs.
 #' @return A ggplot object.
 #' @author Jorge Castillo-Mateo
 #' @seealso \code{\link{N.record}}, \code{\link{N.test}}, 
 #'   \code{\link{foster.test}}, \code{\link{foster.plot}}
 #' @references 
-#' Cebrián A, Castillo-Mateo J, Asín J (2021).
+#' Cebrián AC, Castillo-Mateo J, Asín J (2022).
 #' “Record Tests to Detect Non Stationarity in the Tails with an Application to Climate Change.”
-#' Available at Research Square \doi{10.21203/rs.3.rs-214787/v1}
+#' \emph{Stochastic Environmental Research and Risk Assessment}, \strong{36}(2): 313-330. 
+#' \doi{10.1007/s00477-021-02122-w}
 #' 
 #' @examples
-#' # Plot at Zaragoza, with linear weights and error bar as CIs aesthetic
+#' # Plot at Zaragoza, with linear weights and error bar as RIs aesthetic
 #' N.plot(ZaragozaSeries, weights = function(t) t-1, conf.aes = "errorbar")
 #' 
 #' # Plot only upper records
@@ -107,6 +108,7 @@ N.plot <- function(X,
   if (!is.function(weights)) { stop("'weights' should be a function") }
   backward <- match.arg(backward)
   conf.aes <- match.arg(conf.aes)
+  record   <- as.logical(record)
   
   DNAME <- deparse(substitute(X))
   fun   <- deparse(weights)[2]
@@ -171,19 +173,19 @@ N.plot <- function(X,
     ggplot2::labs(title = METHOD, subtitle = paste("Data:", DNAME), x = "Time", y = ylabel) +
     ggplot2::geom_line(ggplot2::aes(y = mu, linetype = "CI"), colour = conf.col) +
     ggplot2::theme(legend.position = "bottom") +
-    ggplot2::scale_colour_manual(name = "Records", values = point.col, label = c("FU" = "Forward Upper", "FL" = "Forward Lower", "BU" = "Backward Upper", "BL" = "Backward Lower"), breaks = c("FU", "FL", "BU", "BL")) +
-    ggplot2::scale_shape_manual(name = "Records", values = point.shape, label = c("FU" = "Forward Upper", "FL" = "Forward Lower", "BU" = "Backward Upper", "BL" = "Backward Lower"), breaks = c("FU", "FL", "BU", "BL")) +
+    ggplot2::scale_colour_manual(name = "Records", values = point.col[record], label = c("FU" = "Forward Upper", "FL" = "Forward Lower", "BU" = "Backward Upper", "BL" = "Backward Lower")[record], breaks = c("FU", "FL", "BU", "BL")[record]) +
+    ggplot2::scale_shape_manual(name = "Records", values = point.shape[record], label = c("FU" = "Forward Upper", "FL" = "Forward Lower", "BU" = "Backward Upper", "BL" = "Backward Lower")[record], breaks = c("FU", "FL", "BU", "BL")[record]) +
     ggplot2::guides(colour = ggplot2::guide_legend(order = 1), shape = ggplot2::guide_legend(order = 1), linetype = ggplot2::guide_legend(order = 2))
   ###################################
   # plot CI
   if (conf.int && conf.aes == "ribbon") {
     graf <- graf +
       ggplot2::geom_ribbon(ggplot2::aes(ymin = CI1, ymax = CI2, linetype = "CI"), alpha = 0.1, colour = conf.col) +
-      ggplot2::scale_linetype_manual(name = "Null hyp. IID", values = c("CI" = 1), label = c("CI" = paste0("Expectation and ", 100 * conf.level, "% Normal CIs")))
+      ggplot2::scale_linetype_manual(name = "Null hyp. IID", values = c("CI" = 1), label = c("CI" = paste0("Expectation and ", 100 * conf.level, "% Normal RI")))
   } else if (conf.int && conf.aes == "errorbar") { 
     graf <- graf +
       ggplot2::geom_errorbar(ggplot2::aes(ymin = CI1, ymax = CI2, linetype = 'CI'), width = 0.2, colour = conf.col) +
-      ggplot2::scale_linetype_manual(name = "Null hyp. IID", values = c("CI" = 1), label = c("CI" = paste0("Expectation and ", 100 * conf.level, "% Normal CIs")))
+      ggplot2::scale_linetype_manual(name = "Null hyp. IID", values = c("CI" = 1), label = c("CI" = paste0("Expectation and ", 100 * conf.level, "% Normal RI")))
   } else {
     graf <- graf +
       ggplot2::scale_linetype_manual(name = "Null hyp. IID", values = c("CI" = 1), label = c("CI" = "Expectation"))
