@@ -20,18 +20,18 @@
 #'   The expected values under the classical record model are \eqn{1} for any
 #'   value \eqn{t}, so that a cloud of points around \eqn{1} and with no trend
 #'   should be expected. The estimated values are plotted, together with 
-#'   binomial confidence intervals (CIs). In addition, a smoothing function
+#'   binomial reference intervals (RIs). In addition, a smoothing function
 #'   can be fitted to the cloud of points.
 #'   
 #'   Type 2 is the plot of the estimated record probabilities \eqn{p_t} versus
 #'   time \eqn{t}. The expected probabilities under the classical record model, 
-#'   \eqn{p_t=1/t}, are also plotted, together with binomial CIs. 
+#'   \eqn{p_t=1/t}, are also plotted, together with binomial RIs. 
 #'   
 #'   Type 3 is the same plot but on a logarithmic scale, so that the
 #'   expected value is \eqn{-\log(t)}. In this case, another smoothing 
 #'   function can be fitted to the cloud of points.
 #'   
-#'   Type 1 plot was proposed by Cebrián, Castillo-Mateo, Asín (2021), while 
+#'   Type 1 plot was proposed by Cebrián, Castillo-Mateo, Asín (2022), while 
 #'   type 2 and 3 appear in Benestad (2003, Figures 8 and 9, 2004, Figure 4).
 #'
 #' @param X A numeric vector, matrix (or data frame).
@@ -44,13 +44,13 @@
 #' @param point.col,point.shape Vector with four elements indicating the colour
 #'   and shape of the points. Every one of the four elements represents forward
 #'   upper, forward lower, backward upper and backward lower, respectively.
-#' @param conf.int Logical. Indicates if the CIs are also shown.
-#' @param conf.level (If \code{conf.int == TRUE}) Confidence level of the CIs.
+#' @param conf.int Logical. Indicates if the RIs are also shown.
+#' @param conf.level (If \code{conf.int == TRUE}) Confidence level of the RIs.
 #' @param conf.aes (If \code{conf.int == TRUE}) A character string indicating 
-#'   the aesthetic to display for the CIs, \code{"ribbon"} (grey area) or 
+#'   the aesthetic to display for the RIs, \code{"ribbon"} (grey area) or 
 #'   \code{"errorbar"} (vertical lines).
 #' @param conf.col Colour used to plot the expected value and (if 
-#'   \code{conf.int == TRUE}) CIs.
+#'   \code{conf.int == TRUE}) RIs.
 #' @param smooth (If \code{plot = 1} or \code{3}) Logical. If \code{TRUE}, a
 #'   smoothing in the probabilities is also plotted.
 #' @param smooth.formula (\code{smooth = TRUE}) \code{\link{formula}} to use 
@@ -78,9 +78,11 @@
 #' “Record-Values, Nonstationarity Tests and Extreme Value Distributions.” 
 #' \emph{Global and Planetary Change}, \strong{44}(1–4), 11–26. 
 #' 
-#' Cebrián A, Castillo-Mateo J and Asín J (2021).
+#' Cebrián AC, Castillo-Mateo J, Asín J (2022).
 #' “Record Tests to Detect Non Stationarity in the Tails with an Application to Climate Change.”
-#' Available at Research Square \doi{10.21203/rs.3.rs-214787/v1}
+#' \emph{Stochastic Environmental Research and Risk Assessment}, \strong{36}(2): 313-330. 
+#' \doi{10.1007/s00477-021-02122-w}
+#' 
 #' @examples
 #' # three plots available
 #' p.plot(ZaragozaSeries, plot = 1)
@@ -124,6 +126,7 @@ p.plot <- function(X,
   plot <- as.character(plot)
   plot <- match.arg(plot)
   conf.aes <- match.arg(conf.aes)
+  record   <- as.logical(record)
   
   DNAME <- deparse(substitute(X))
   Trows <- NROW(X)
@@ -196,11 +199,11 @@ p.plot <- function(X,
   if (conf.int && conf.aes == "ribbon") {
     graf <- graf + 
       ggplot2::geom_ribbon(ggplot2::aes(ymin = CI1, ymax = CI2, size = "CI"), alpha = 0.1, colour = conf.col) +
-      ggplot2::scale_size_manual(name = "Null hyp. IID", values = c("CI" = 0.5), label = c("CI" = paste0("Expectation and ", 100 * conf.level, "% Binomial CI")))
+      ggplot2::scale_size_manual(name = "Null hyp. IID", values = c("CI" = 0.5), label = c("CI" = paste0("Expectation and ", 100 * conf.level, "% Binomial RI")))
   } else if (conf.int && conf.aes == "errorbar") {
     graf <- graf + 
       ggplot2::geom_errorbar(ggplot2::aes(ymin = CI1, ymax = CI2, size = "CI"), width = 0.2, colour = conf.col) +
-      ggplot2::scale_size_manual(name = "Null hyp. IID", values = c("CI" = 0.5), label = c("CI" = paste0("Expectation and ", 100 * conf.level, "% Binomial CI")))
+      ggplot2::scale_size_manual(name = "Null hyp. IID", values = c("CI" = 0.5), label = c("CI" = paste0("Expectation and ", 100 * conf.level, "% Binomial RI")))
   } else {
     graf <- graf +
       ggplot2::scale_size_manual(name = "Null hyp. IID", values = c("CI" = 0.5), label = c("CI" = "Expectation"))
@@ -219,14 +222,15 @@ p.plot <- function(X,
     if (record[1]) { graf <- graf + ggplot2::geom_smooth(formula = smooth.formula, method = smooth.method, ..., mapping = ggplot2::aes(y = p.FU, weight = weights, colour = "FU", linetype = "FU"), se = FALSE, alpha = 0.1) }
   
     graf <- graf + 
-      ggplot2::scale_linetype_manual(name = "Records", values = smooth.linetype, label = c("FU" = "Forward Upper", "FL" = "Forward Lower", "BU" = "Backward Upper", "BL" = "Backward Lower"), breaks = c("FU", "FL", "BU", "BL"))
+      ggplot2::scale_linetype_manual(name = "Records", values = smooth.linetype[record], label = c("FU" = "Forward Upper", "FL" = "Forward Lower", "BU" = "Backward Upper", "BL" = "Backward Lower")[record], breaks = c("FU", "FL", "BU", "BL")[record])
   }
   ###################################
      
   graf <- graf + 
-    ggplot2::scale_colour_manual(name = "Records", values = point.col, label = c("FU" = "Forward Upper", "FL" = "Forward Lower", "BU" = "Backward Upper", "BL" = "Backward Lower"), breaks = c("FU", "FL", "BU", "BL")) +
-    ggplot2::scale_shape_manual(name = "Records", values = point.shape, label = c("FU" = "Forward Upper", "FL" = "Forward Lower", "BU" = "Backward Upper", "BL" = "Backward Lower"), breaks = c("FU", "FL", "BU", "BL")) +
-    ggplot2::theme(legend.position = "bottom")
+    ggplot2::scale_colour_manual(name = "Records", values = point.col[record], label = c("FU" = "Forward Upper", "FL" = "Forward Lower", "BU" = "Backward Upper", "BL" = "Backward Lower")[record], breaks = c("FU", "FL", "BU", "BL")[record]) +
+    ggplot2::scale_shape_manual(name = "Records", values = point.shape[record], label = c("FU" = "Forward Upper", "FL" = "Forward Lower", "BU" = "Backward Upper", "BL" = "Backward Lower")[record], breaks = c("FU", "FL", "BU", "BL")[record]) +
+    ggplot2::theme(legend.position = "bottom") +
+    ggplot2::guides(colour = ggplot2::guide_legend(order = 1), shape = ggplot2::guide_legend(order = 1), linetype = ggplot2::guide_legend(order = 1), size = ggplot2::guide_legend(order = 2))
   
   return(graf)
-}
\ No newline at end of file
+}
